.. _pagetemplate_api_module:

:mod:`z3c.pt`
--------------------------

``PageTemplate*`` constructors create templates from XML
files. ``TextTemplate*`` constructors create templates from plaintext
files.

.. automodule:: z3c.pt

  .. autoclass:: PageTemplate

  .. autoclass:: PageTemplateFile

  .. autoclass:: TextTemplate

  .. autoclass:: TextTemplateFile

